@@ -10,6 +10,7 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Description:" : "Descripción:",
     "Where:" : "Dónde:",
+    "Location:" : "Ubicación:",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -28,7 +29,6 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Share link" : "Compartir liga",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
@@ -36,10 +36,14 @@ OC.L10N.register(
     "Filename" : "Nombre del archivo",
     "Cancel" : "Cancelar",
     "Automatic" : "Automático",
+    "Automatic ({timezone})" : "({timezone}) automática",
+    "Timezone" : "Zona horaria",
     "List view" : "Vista de lista",
     "Actions" : "Acciones",
     "or" : "o",
+    "General" : "General",
     "Show week numbers" : "Mostrar número de semana",
+    "Keyboard shortcuts" : "Atajos del teclado",
     "Update" : "Actualizar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
@@ -70,13 +74,17 @@ OC.L10N.register(
     "after" : "después",
     "Resources" : "Recursos",
     "available" : "disponible",
+    "Yes" : "Si",
+    "None" : "Ninguno",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
     "Edit event" : "Editar evento",
     "All day" : "Todo el día",
     "Close" : "Cerrar",
+    "Title" : "Título",
     "Participants" : "Participantes",
+    "Submit" : "Enviar",
     "Anniversary" : "Aniversario",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Daily" : "Diariamente",
@@ -89,6 +97,7 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
