@@ -111,7 +111,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["휴지통에 있는 항목은 {numDays}일 수 완전히 삭제됩니다"],
     "Could not update calendar order." : "달력 순서를 갱신할 수 없습니다.",
     "Deck" : "덱",
-    "Hidden" : "숨겨짐",
     "Internal link" : "내부 링크",
     "A private link that can be used with external clients" : "개인 링크를 외부 클라이언트에서 사용할 수 있습니다",
     "Copy internal link" : "내부 링크 복사",
@@ -160,7 +159,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n개의 일정을 성공적으로 가져옴"],
     "Import partially failed. Imported {accepted} out of {total}." : "가져오기가 부분적으로 실패했습니다. {total} 중 {accepted} 가져옴.",
     "Automatic" : "자동",
-    "Automatic ({detected})" : "자동 ({detected})",
+    "Automatic ({timezone})" : "자동({timezone})",
     "New setting was not saved successfully." : "새로운 설정이 저장되지 않았습니다.",
     "Timezone" : "시간대",
     "Navigation" : "탐색",
@@ -371,6 +370,7 @@ OC.L10N.register(
     "Yes" : "예",
     "No" : "아니오",
     "Maybe" : "아마도",
+    "None" : "없음",
     "Create" : "생성",
     "from {formattedDate}" : "{formattedDate} 부터",
     "to {formattedDate}" : "{formattedDate} 까지",
@@ -516,6 +516,8 @@ OC.L10N.register(
     "This is an event reminder." : "일정에 대한 알림입니다.",
     "Appointment not found" : "약속을 찾을 수 없음",
     "User not found" : "사용자를 찾을 수 없음",
+    "Hidden" : "숨겨짐",
+    "Automatic ({detected})" : "자동 ({detected})",
     "Shortcut overview" : "바로가기 개요",
     "Enable simplified editor" : "간편한 편집기 활성화",
     "Limit the number of events displayed in the monthly view" : "월간 보기에서 표시되는 일정의 수 제한",
