@@ -41,7 +41,14 @@ OC.L10N.register(
     "Comment:" : "Коментар:",
     "You have a new appointment booking \"%s\" from %s" : "Имате нов закажан состанок \"%s\" од %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Почитуван/а %s, %s (%s) закажа состанок со вас.",
+    "%s has proposed a meeting" : "%s предложи состанок",
+    "%s has updated a proposed meeting" : "%s го ажурираше предложениот состанок",
+    "%s has canceled a proposed meeting" : "%s го откажа предложениот состанок",
     "Location:" : "Локација:",
+    "Duration:" : "Времетраење:",
+    "%1$s from %2$s to %3$s" : "%1$s од %2$s до %3$s",
+    "Dates:" : "Датуми:",
+    "Respond" : "Одговори",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
     "Previous week" : "Предходна недела",
@@ -115,7 +122,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Shared calendars" : "Споделени календари",
     "Deck" : "Deck",
-    "Hidden" : "Сокриен",
     "Internal link" : "Внатрешен линк",
     "A private link that can be used with external clients" : "Приватен линк што може да се користи со надворешни клиенти",
     "Copy internal link" : "Копирај внатрешен линк",
@@ -148,6 +154,13 @@ OC.L10N.register(
     "Share calendar" : "Сподели календар",
     "Unshare from me" : "Не споделувај со мене",
     "Save" : "Зачувај",
+    "No title" : "Нема наслов",
+    "Are you sure you want to delete \"{title}\"?" : "Дали сте сигурни дека сакате да го избришете \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Бришење на предлогот \"{title}\"",
+    "Successfully deleted proposal" : "Успешно бришење на предлог",
+    "Failed to delete proposal" : "Неуспешно бришење на предлог",
+    "Meeting proposals" : "Предлози за состаноци",
+    "No active meeting proposals" : "Нема активен предлог за состаноци",
     "View" : "Поглед",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
@@ -166,7 +179,7 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Успешно увезен 1 настан","Успешно увезени %n настани"],
     "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
     "Automatic" : "Автоматски",
-    "Automatic ({detected})" : "Автоматски ({detected})",
+    "Automatic ({timezone})" : "Автоматски ({timezone})",
     "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
     "Navigation" : "Навигација",
     "Previous period" : "Предходен период",
@@ -185,7 +198,6 @@ OC.L10N.register(
     "Save edited event" : "Зачувај го изменетиот настан",
     "Delete edited event" : "Избриши го изменетиот настан",
     "Duplicate event" : "Дуплирај настај",
-    "Shortcut overview" : "Преглед на кратенки преку тастатура",
     "or" : "или",
     "Calendar settings" : "Параметри за календар",
     "At event start" : "На почетокот на настанот",
@@ -193,19 +205,17 @@ OC.L10N.register(
     "Failed to save default calendar" : "Неуспешно зачувување на стандарден календар",
     "CalDAV link copied to clipboard." : "CalDAV линкот е копиран.",
     "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
-    "Enable birthday calendar" : "Овозможи календар со родендени",
-    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
-    "Enable simplified editor" : "Овозможи поедноставен уредувач",
-    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
-    "Show weekends" : "Прикажи викенди",
-    "Show week numbers" : "Прикажи броеви на неделите",
-    "Time increments" : "Временско зголемување",
-    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
-    "Default reminder" : "Стандарден потсетник",
+    "General" : "Општо",
+    "Personal availability settings" : "Параметри за лична достапност",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
     "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
-    "Personal availability settings" : "Параметри за лична достапност",
-    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура",
+    "Enable birthday calendar" : "Овозможи календар со родендени",
+    "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
+    "Show weekends" : "Прикажи викенди",
+    "Show week numbers" : "Прикажи броеви на неделите",
+    "Default calendar for incoming invitations" : "Стандарден календар за дојдовни покани",
+    "Default reminder" : "Стандарден потсетник",
+    "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Appointment schedule successfully created" : "Распоред за состаноци е успешно креиран",
     "Appointment schedule successfully updated" : "Распоред за состаноци е успешно ажуриран",
     "_{duration} minute_::_{duration} minutes_" : ["1 минута","{duration} минути"],
@@ -355,6 +365,7 @@ OC.L10N.register(
     "Search for emails, users, contacts, contact groups or teams" : "Пребарувај за е-пошти, корисници, контакти, групи или тимови",
     "No match found" : "Нема совпаѓања",
     "(organizer)" : "(organizer)",
+    "Make {label} the organizer" : "Направи го {label} организатор",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "За да испратите покана и да можете да добивате одговори,  [linkopen]додадете ја вашата е-пошта адреса во личните податоци на сметката[linkclose].",
     "Remove color" : "Отстрани боја",
     "Event title" : "Наслов на настанот",
@@ -406,7 +417,14 @@ OC.L10N.register(
     "Update this occurrence" : "Ажурирајте ја оваа можност",
     "Public calendar does not exist" : "Јавниот календар не постои",
     "Maybe the share was deleted or has expired?" : "Можеби споделувањето е избришано ики рокот му е поминат?",
+    "Remove date" : "Избриши датум",
+    "Attendance required" : "Потребно е присуство",
+    "Attendance optional" : "Присуството е опционално",
     "Remove participant" : "Одстрани учесник",
+    "Yes" : "Да",
+    "No" : "Не",
+    "Maybe" : "Можеби",
+    "None" : "Ништо",
     "Create" : "Креирај",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
@@ -463,7 +481,37 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Прилог за кој е потребен пристап","Прилози за кои е потребен пристап"],
     "Untitled event" : "Неименуван настан",
     "Close" : "Затвори",
+    "Edit meeting proposal" : "Измени предлог за состанок",
+    "Create meeting proposal" : "Креирај предлог за состанок",
+    "Update meeting proposal" : "Ажурирај предлог за состанок",
+    "Saving proposal \"{title}\"" : "Зачуван предлог \"{title}\"",
+    "Successfully saved proposal" : "Успешно зачуван предлог",
+    "Failed to save proposal" : "Неуспешно зачувување на предлог",
+    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Креирај состанок за \"{date}\"? Ова ќе креира настан во календарот со сите учесници.",
+    "Creating meeting for {date}" : "Креирање состанок за {date}",
+    "Successfully created meeting for {date}" : "Успешно креиран состанок за {date}",
+    "Failed to create a meeting for {date}" : "Неуспешно креиран состанок за {date}",
+    "Please enter a valid duration in minutes." : "Внесете валидно времетраење во минути.",
+    "Selected" : "Избрани",
+    "No Description" : "Нема опис",
+    "No Location" : "Нема локација",
+    "Edit this meeting proposal" : "Измени го овој предлог за состанок",
+    "Delete this meeting proposal" : "Избриши го овој предлог за состанок",
+    "Title" : "Наслов",
+    "15 min" : "15 мин",
+    "30 min" : "30 мин",
+    "60 min" : "60 мин",
+    "90 min" : "90 мин",
     "Participants" : "Учесници",
+    "Selected times" : "Избрани времиња",
+    "More days" : "Повеќе денови",
+    "Thank you for your response!" : "Благодариме на вашиот одговор.",
+    "Your vote has been recorded. Thank you for participating!" : "Вашиот глас е регистриран. Благодариме за учеството!",
+    "Unknown User" : "Непознат корисник",
+    "No Title" : "Нема наслов",
+    "No Duration" : "Нема времетраење",
+    "Select a different time zone" : "Избери различна временска зона",
+    "Submit" : "Испрати",
     "Subscribe to {name}" : "Претплатете се на {name}",
     "Export {name}" : "Извези {name}",
     "Show availability" : "Прикажи достапност",
@@ -482,7 +530,7 @@ OC.L10N.register(
     "Travel" : "Патување",
     "Vacation" : "Одмор",
     "Midnight on the day the event starts" : "На полноќ на денот кога започнува настанот",
-    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Еден ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
+    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n ден пред настанот во {formattedHourMinute}","%n дена пред настанот во {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["Една недела пред настанот во {formattedHourMinute}","%n недели пред настанот во {formattedHourMinute}"],
     "on the day of the event at {formattedHourMinute}" : "На денот на настанот во {formattedHourMinute}",
     "at the event's start" : "на почетокот на настанот",
@@ -508,7 +556,7 @@ OC.L10N.register(
     "in {monthNames} on the {dayOfMonthList}" : "во {monthNames} на {dayOfMonthList}",
     "in {monthNames} on the {ordinalNumber} {byDaySet}" : "во {monthNames} на {ordinalNumber} {byDaySet}",
     "until {untilDate}" : "до {untilDate}",
-    "_%n time_::_%n times_" : ["уште еднаш","%n пати"],
+    "_%n time_::_%n times_" : ["%n пат","%n пати"],
     "second" : "втор",
     "third" : "трети",
     "fourth" : "четврти",
@@ -562,6 +610,13 @@ OC.L10N.register(
     "Imported {filename}" : "Импортирано {filename}",
     "This is an event reminder." : "Ова е потсетник за настан.",
     "Appointment not found" : "Терминот не е пронајден",
-    "User not found" : "Корисникот не е пронајден"
+    "User not found" : "Корисникот не е пронајден",
+    "Hidden" : "Сокриен",
+    "Automatic ({detected})" : "Автоматски ({detected})",
+    "Shortcut overview" : "Преглед на кратенки преку тастатура",
+    "Enable simplified editor" : "Овозможи поедноставен уредувач",
+    "Limit the number of events displayed in the monthly view" : "Ограничи број на настани прикажани во месечниот преглед",
+    "Time increments" : "Временско зголемување",
+    "Show keyboard shortcuts" : "Прикажи кратенки преку тастатура"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
