@@ -41,6 +41,17 @@ OC.L10N.register(
     "Comment:" : "Kommentar:",
     "You have a new appointment booking \"%s\" from %s" : "Du har en ny mötesbokning \"%s\" från %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) bokade ett möte med dig.",
+    "%s has proposed a meeting" : "%s har föreslagit ett möte",
+    "%s has updated a proposed meeting" : "%s har uppdaterat ett föreslaget möte",
+    "%s has canceled a proposed meeting" : "%s har avbokat ett föreslaget möte",
+    "Dear %s, a new meeting has been proposed" : "Hej %s, ett nytt möte har föreslagits",
+    "Dear %s, a proposed meeting has been updated" : "Hej %s, ett föreslaget möte har uppdaterats",
+    "Dear %s, a proposed meeting has been cancelled" : "Hej %s, ett föreslaget möte har avbokats",
+    "Location:" : "Ort:",
+    "Duration:" : "Varaktighet:",
+    "%1$s from %2$s to %3$s" : "%1$s från %2$s till %3$s",
+    "Dates:" : "Datum:",
+    "Respond" : "Svara",
     "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Previous day" : "Föregående dag",
     "Previous week" : "Föregående vecka",
@@ -114,7 +125,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Det gick inte att uppdatera kalenderordningen.",
     "Shared calendars" : "Delade kalendrar",
     "Deck" : "Deck",
-    "Hidden" : "Gömd",
     "Internal link" : "Intern länk",
     "A private link that can be used with external clients" : "En privat länk som kan användas med externa klienter",
     "Copy internal link" : "Kopiera intern länk",
@@ -147,6 +157,16 @@ OC.L10N.register(
     "Share calendar" : "Dela kalender",
     "Unshare from me" : "Sluta dela från mig",
     "Save" : "Spara",
+    "No title" : "Ingen titel",
+    "Are you sure you want to delete \"{title}\"?" : "Är du säker på att du vill ta bort \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Tar bort förslaget \"{title}\"",
+    "Successfully deleted proposal" : "Förslaget har tagits bort",
+    "Failed to delete proposal" : "Kunde inte ta bort förslaget",
+    "Failed to retrieve proposals" : "Kunde inte hämta förslag",
+    "Meeting proposals" : "Mötesförslag",
+    "A configured email address is required to use meeting proposals" : "En konfigurerad e-postadress krävs för att använda mötesförslag",
+    "No active meeting proposals" : "Inga aktiva mötesförslag",
+    "View" : "Visa",
     "Import calendars" : "Importera kalendrar",
     "Please select a calendar to import into …" : "Vänligen välj en kalender du vill importera till …",
     "Filename" : "Filnamn",
@@ -164,8 +184,9 @@ OC.L10N.register(
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Lyckades importera %n händelse","Lyckades importera %n händelser"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importen misslyckades delvis. Importerade {accepted} av {total}.",
     "Automatic" : "Automatisk",
-    "Automatic ({detected})" : "Automatisk ({detected})",
+    "Automatic ({timezone})" : "Automatisk ({timezone})",
     "New setting was not saved successfully." : "Den nya inställningen kunde inte sparas.",
+    "Timezone" : "Tidszon",
     "Navigation" : "Navigering",
     "Previous period" : "Föregående period",
     "Next period" : "Nästa period",
@@ -183,7 +204,6 @@ OC.L10N.register(
     "Save edited event" : "Spara ändrad händelse",
     "Delete edited event" : "Radera ändrad händelse",
     "Duplicate event" : "Duplicera händelse",
-    "Shortcut overview" : "Översikt av genvägar",
     "or" : "eller",
     "Calendar settings" : "Kalenderinställningar",
     "At event start" : "Vid händelsens start",
@@ -191,19 +211,22 @@ OC.L10N.register(
     "Failed to save default calendar" : "Det gick inte att spara standardkalendern",
     "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
     "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
-    "Enable birthday calendar" : "Aktivera födelsedagskalender",
-    "Show tasks in calendar" : "Visa uppgifter i kalendern",
-    "Enable simplified editor" : "Aktivera förenklad redigerare",
-    "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
-    "Show weekends" : "Visa helger",
-    "Show week numbers" : "Visa veckonummer",
-    "Time increments" : "Tidsintervall",
-    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
-    "Default reminder" : "Standardpåminnelse",
+    "General" : "Allmänt",
+    "Personal availability settings" : "Dina tillgänglighetsinställningar",
     "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
     "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
-    "Personal availability settings" : "Dina tillgänglighetsinställningar",
-    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
+    "View options" : "Visningsalternativ",
+    "Enable birthday calendar" : "Aktivera födelsedagskalender",
+    "Show tasks in calendar" : "Visa uppgifter i kalendern",
+    "Show weekends" : "Visa helger",
+    "Show week numbers" : "Visa veckonummer",
+    "Limit number of events shown in month view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Time division in day and week view" : "Tidsindelning i dag- och vecko­vy",
+    "Editing" : "Ändrar",
+    "Enable simple editor" : "Aktivera enkel redigerare",
+    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
+    "Default reminder" : "Standardpåminnelse",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Appointment schedule successfully created" : "Mötesschema skapat",
     "Appointment schedule successfully updated" : "Mötesschema uppdaterat",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuter"],
@@ -268,11 +291,10 @@ OC.L10N.register(
     "Add Talk conversation" : "Lägg till Talk-konversation",
     "Fetching Talk rooms…" : "Hämtar Talk-rum...",
     "No Talk room available" : "Inget Talk-rum tillgängligt",
-    "Create a new conversation" : "Skapa en ny konversation",
+    "Create a new public conversation" : "Skapa en ny offentlig konversation",
     "Select conversation" : "Välj konversation",
     "on" : "den",
     "at" : "kl",
-    "Reminder" : "Påminnelse",
     "before at" : "innan",
     "Notification" : "Notifiering",
     "Email" : "E-post",
@@ -283,7 +305,6 @@ OC.L10N.register(
     "Edit time" : "Ändra tid",
     "Save time" : "Lagra tid",
     "Remove reminder" : "Ta bort påminnelse",
-    "+ Add reminder" : "+ Lägg till påminnelse",
     "Add reminder" : "Lägg till påminnelse",
     "seconds" : "sekunder",
     "minutes" : "minuter",
@@ -319,26 +340,28 @@ OC.L10N.register(
     "Awaiting response" : "Väntar på svar",
     "Checking availability" : "Kontrollerar tillgänglighet",
     "Has not responded to {organizerName}'s invitation yet" : "Har ej svarat på inbjudan från {organizerName} än",
-    "Select automatic slot" : "Välj automatisk lucka",
+    "Suggested times" : "Föreslagna tider",
     "chairperson" : "ordförande",
     "required participant" : "obligatorisk deltagare",
     "non-participant" : "icke-deltagare",
     "optional participant" : "valfri deltagare",
     "{organizer} (organizer)" : "{organizer} (arrangör)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Ledig",
-    "Busy (tentative)" : "Upptagen (preliminär)",
-    "Busy" : "Upptagen",
-    "Out of office" : "Ej på plats",
-    "Unknown" : "Okänd",
     "Availability of attendees, resources and rooms" : "Tillgänglighet för deltagare, resurser och lokaler",
-    "with" : "med",
-    "Available times:" : "Tillgängliga tider:",
     "Suggestion accepted" : "Förslaget accepterat",
+    "Previous date" : "Föregående datum",
+    "Next date" : "Nästa datum",
+    "Legend" : "Etikett",
+    "Out of office" : "Ej på plats",
+    "Attendees:" : "Deltagare:",
     "Done" : "Klar",
     "Search room" : "Sök rum",
     "Room name" : "Rumsnamn",
     "Check room availability" : "Kontrollera rums tillgänglighet",
+    "Free" : "Ledig",
+    "Busy (tentative)" : "Upptagen (preliminär)",
+    "Busy" : "Upptagen",
+    "Unknown" : "Okänd",
     "Find a time" : "Hitta en tid",
     "The invitation has been accepted successfully." : "Inbjudan har accepterats",
     "Failed to accept the invitation." : "Misslyckades med att acceptera inbjudan.",
@@ -378,8 +401,8 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan inte ändra inställning för heldag när händelsen är återkommande.",
     "From" : "Från",
     "To" : "Till",
-    "All day" : "Heldag",
     "Repeat" : "Upprepa",
+    "Repeat event" : "Upprepa händelse",
     "_time_::_times_" : ["gång","gånger"],
     "never" : "aldrig",
     "on date" : "på datum",
@@ -402,7 +425,7 @@ OC.L10N.register(
     "Does not repeat" : "Upprepar inte",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Återkommande definition av denna händelse stöds inte helt av Nextcloud. Om du redigerar återfallsalternativen kan vissa återfall försvinna.",
     "No rooms or resources yet" : "Inga rum eller resurser än",
-    "Suggestions" : "Rekommendationer",
+    "Resources" : "Resurser",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} plats","{seatingCapacity} platser"],
     "Add resource" : "Lägg till resurs",
     "Has a projector" : "Projektor finns",
@@ -423,6 +446,18 @@ OC.L10N.register(
     "Update this occurrence" : "Uppdatera denna förekomst",
     "Public calendar does not exist" : "Publik kalender finns inte",
     "Maybe the share was deleted or has expired?" : "Kanske har delningen tagits bort eller har gått ut?",
+    "Remove date" : "Ta bort datum",
+    "Attendance required" : "Närvaro krävs",
+    "Attendance optional" : "Närvaro frivillig",
+    "Remove participant" : "Ta bort deltagare",
+    "Yes" : "Ja",
+    "No" : "Nej",
+    "Maybe" : "Kanske",
+    "None" : "Ingen",
+    "Select your meeting availability" : "Välj din tillgänglighet",
+    "Create a meeting for this date and time" : "Skapa ett möte för detta datum och tid",
+    "Create" : "Skapa",
+    "No participants or dates available" : "Inga deltagare eller datum tillgängliga",
     "from {formattedDate}" : "från {formattedDate}",
     "to {formattedDate}" : "till {formattedDate}",
     "on {formattedDate}" : "på {formattedDate}",
@@ -446,7 +481,7 @@ OC.L10N.register(
     "No valid public calendars configured" : "Inga giltiga publika kalendrar konfigurerade",
     "Speak to the server administrator to resolve this issue." : "Kontakta serveradministratören för att lösa detta problem.",
     "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Helgdagskalendrar tillhandahålls av Thunderbird. Kalenderdata kommer att laddas ner från {website}",
-    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Dessa publika kalendrar föreslås av serveradministratören. Kalenderdata kommer att hämtas från respektive webbplats.",
+    "These public calendars are suggested by the server administrator. Calendar data will be downloaded from the respective website." : "Dessa offentliga kalendrar föreslås av serveradministratören. Kalenderdata kommer att hämtas från respektive webbplats.",
     "By {authors}" : "Av {authors}",
     "Subscribed" : "Prenumeration aktiverad",
     "Subscribe" : "Prenumerera",
@@ -468,22 +503,65 @@ OC.L10N.register(
     "Personal" : "Privat",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Den automatiska tidszon-detekteringen fastställde din tidszon till UTC.\nDetta är troligtvis resultatet av säkerhetsinställningar i din webbläsare.\nVänligen ställ in din tidszon manuellt i kalenderinställningarna.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Din tidszon ({timezoneId}) hittades inte. Återgår till UTC.\nVänligen ändra din tidszon i inställningarna och rapportera detta problem.",
+    "Show unscheduled tasks" : "Visa ej schemalagda uppgifter",
+    "Unscheduled tasks" : "Ej schemalagda uppgifter",
     "Availability of {displayName}" : "Tillgänglighet för {displayName}",
+    "Edit event" : "Redigera händelse",
     "Event does not exist" : "Händelsen existerar inte",
     "Duplicate" : "Duplicera",
     "Delete this occurrence" : "Ta bort denna förekomst",
     "Delete this and all future" : "Ta bort denna och alla kommande",
+    "All day" : "Heldag",
     "Modifications wont get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
-    "Details" : "Detaljer",
     "Managing shared access" : "Hantering av delad åtkomst",
     "Deny access" : "Neka åtkomst",
     "Invite" : "Bjud in",
-    "Resources" : "Resurser",
     "_User requires access to your file_::_Users require access to your file_" : ["En användare behöver tillgång till din fil","Användare behöver tillgång till din fil"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bilaga i behov av delat åtkomst","Bilagor i behov av delad åtkomst"],
     "Untitled event" : "Namnlös händelse",
     "Close" : "Stäng",
     "Modifications will not get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "Meeting proposals overview" : "Översikt över mötesförslag",
+    "Edit meeting proposal" : "Redigera mötesförslag",
+    "Create meeting proposal" : "Skapa mötesförslag",
+    "Update meeting proposal" : "Uppdatera mötesförslag",
+    "Saving proposal \"{title}\"" : "Sparar förslag \"{title}\"",
+    "Successfully saved proposal" : "Förslaget har sparats",
+    "Failed to save proposal" : "Kunde inte spara förslaget",
+    "Create a meeting for \"{date}\"? This will create a calendar event with all participants." : "Skapa ett möte för \"{date}\"? Detta kommer att skapa en kalenderhändelse med alla deltagare.",
+    "Creating meeting for {date}" : "Skapar möte för {date}",
+    "Successfully created meeting for {date}" : "Möte har skapats för {date}",
+    "Failed to create a meeting for {date}" : "Kunde inte skapa möte för {date}",
+    "Please enter a valid duration in minutes." : "Ange en giltig varaktighet i minuter.",
+    "Failed to fetch proposals" : "Kunde inte hämta förslag",
+    "Failed to fetch free/busy data" : "Kunde inte hämta ledig/upptagen-data",
+    "Selected" : "Vald",
+    "No Description" : "Ingen beskrivning",
+    "No Location" : "Ingen plats",
+    "Edit this meeting proposal" : "Redigera detta mötesförslag",
+    "Delete this meeting proposal" : "Ta bort detta mötesförslag",
+    "Title" : "Titel",
+    "15 min" : "15 min",
+    "30 min" : "30 min",
+    "60 min" : "60 min",
+    "90 min" : "90 min",
+    "Participants" : "Deltagare",
+    "Selected times" : "Valda tider",
+    "Previous span" : "Föregående intervall",
+    "Next span" : "Nästa intervall",
+    "Less days" : "Färre dagar",
+    "More days" : "Fler dagar",
+    "Loading meeting proposal" : "Läser in mötesförslag",
+    "No meeting proposal found" : "Inget mötesförslag hittades",
+    "Please wait while we load the meeting proposal." : "Vänligen vänta medan vi läser in mötesförslaget.",
+    "The link you followed may be broken, or the meeting proposal may no longer exist." : "Länken du följde kan vara trasig, eller så finns mötesförslaget inte längre.",
+    "Thank you for your response!" : "Tack för ditt svar!",
+    "Your vote has been recorded. Thank you for participating!" : "Din röst har registrerats. Tack för att du deltog!",
+    "Unknown User" : "Okänd användare",
+    "No Title" : "Ingen titel",
+    "No Duration" : "Ingen varaktighet",
+    "Select a different time zone" : "Välj en annan tidszon",
+    "Submit" : "Skicka",
     "Subscribe to {name}" : "Prenumerera på {name}",
     "Export {name}" : "Exportera {name}",
     "Show availability" : "Visa tillgänglighet",
@@ -576,7 +654,10 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Anpassad färg på denna händelse. Åsidosätter kalenderfärgen.",
     "Error while sharing file" : "Fel vid delning av fil",
     "Error while sharing file with user" : "Ett fel uppstod vid delning av fil med användare",
+    "Error creating a folder {folder}" : "Det gick inte att skapa mappen {folder}",
     "Attachment {fileName} already exists!" : "Bilagan {fileName} finns redan!",
+    "Attachment {fileName} added!" : "Bilaga {fileName} tillagd!",
+    "An error occurred during uploading file {fileName}" : "Ett fel uppstod vid uppladdning av filen {fileName}",
     "An error occurred during getting file information" : "Ett fel uppstod vid hämtning av filinformation",
     "Talk conversation for event" : "Talk-konversation för händelse",
     "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
@@ -584,6 +665,13 @@ OC.L10N.register(
     "This is an event reminder." : "Detta är en händelsepåminnelse.",
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
-    "User not found" : "Användaren hittades inte"
+    "User not found" : "Användaren hittades inte",
+    "Hidden" : "Gömd",
+    "Automatic ({detected})" : "Automatisk ({detected})",
+    "Shortcut overview" : "Översikt av genvägar",
+    "Enable simplified editor" : "Aktivera förenklad redigerare",
+    "Limit the number of events displayed in the monthly view" : "Begränsa antalet händelser som visas i månadsvyn",
+    "Time increments" : "Tidsintervall",
+    "Show keyboard shortcuts" : "Visa tangentbordsgenvägar"
 },
 "nplurals=2; plural=(n != 1);");
